[mpich-commits] [mpich] MPICH primary repository branch, master, updated. v3.2-98-gdb5772f

Service Account noreply at mpich.org
Thu Jan 21 09:42:02 CST 2016


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "MPICH primary repository".

The branch, master has been updated
       via  db5772f6af94274abc0c52e9e8e5fe7b63fb01bd (commit)
      from  31282a08dd74043ee18af6efccab9f2b955e54a8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.mpich.org/mpich.git/commitdiff/db5772f6af94274abc0c52e9e8e5fe7b63fb01bd

commit db5772f6af94274abc0c52e9e8e5fe7b63fb01bd
Author: Ken Raffenetti <raffenet at mcs.anl.gov>
Date:   Mon Jan 18 17:00:12 2016 -0600

    romio: ADIOI_Strnapp -> MPL_strnapp
    
    No need to maintain ROMIO's copy of strnapp now that we embed MPL.
    
    Signed-off-by: Rob Latham <robl at mcs.anl.gov>

diff --git a/src/mpi/romio/adio/common/strfns.c b/src/mpi/romio/adio/common/strfns.c
index b44210a..14cf81c 100644
--- a/src/mpi/romio/adio/common/strfns.c
+++ b/src/mpi/romio/adio/common/strfns.c
@@ -66,58 +66,6 @@ int ADIOI_Strncpy( char *dest, const char *src, size_t n )
 	return 1;
 }
 
-/* Append src to dest, but only allow dest to contain n characters (including
-   any null, which is always added to the end of the line */
-/*@ ADIOI_Strnapp - Append to a string with a maximum length
-
-Input Parameters:
-+   instr - String to copy
--   maxlen - Maximum total length of 'outstr'
-
-Output Parameters:
-.   outstr - String to copy into
-
-    Notes:
-    This routine is similar to 'strncat' except that the 'maxlen' argument
-    is the maximum total length of 'outstr', rather than the maximum 
-    number of characters to move from 'instr'.  Thus, this routine is
-    easier to use when the declared size of 'instr' is known.
-
-  Module:
-  Utility
-  @*/
-int ADIOI_Strnapp( char *dest, const char *src, size_t n )
-{
-    char * restrict d_ptr = dest;
-    const char * restrict s_ptr = src;
-    register int i;
-
-    /* Get to the end of dest */
-    i = (int)n;
-    while (i-- > 0 && *d_ptr) d_ptr++;
-    if (i <= 0) return 1;
-
-    /* Append.  d_ptr points at first null and i is remaining space. */
-    while (*s_ptr && i-- > 0) {
-	*d_ptr++ = *s_ptr++;
-    }
-
-    /* We allow i >= (not just >) here because the first while decrements
-       i by one more than there are characters, leaving room for the null */
-    if (i >= 0) { 
-	*d_ptr = 0;
-	return 0;
-    }
-    else {
-	/* Force the null at the end */
-	*--d_ptr = 0;
-    
-	/* We may want to force an error message here, at least in the
-	   debugging version */
-	return 1;
-    }
-}
-
 /*@ 
   ADIOI_Strdup - Duplicate a string
 
diff --git a/src/mpi/romio/adio/include/adioi.h b/src/mpi/romio/adio/include/adioi.h
index b4e0d3c..1ab9d81 100644
--- a/src/mpi/romio/adio/include/adioi.h
+++ b/src/mpi/romio/adio/include/adioi.h
@@ -920,7 +920,6 @@ int ADIOI_Set_lock64(FDTYPE fd_sys, int cmd, int type, ADIO_Offset offset, int w
 #define ADIOI_Free(a) ADIOI_Free_fn(a,__LINE__,__FILE__)
 
 int ADIOI_Strncpy( char *outstr, const char *instr, size_t maxlen );
-int ADIOI_Strnapp( char *, const char *, size_t );
 char *ADIOI_Strdup( const char * );
 
 /* the current MPI standard is not const-correct, and modern compilers warn

-----------------------------------------------------------------------

Summary of changes:
 src/mpi/romio/adio/common/shfp_fname.c |    4 +-
 src/mpi/romio/adio/common/strfns.c     |   52 --------------------------------
 src/mpi/romio/adio/include/adioi.h     |    1 -
 3 files changed, 2 insertions(+), 55 deletions(-)


hooks/post-receive
diff --git a/src/mpi/romio/adio/common/shfp_fname.c b/src/mpi/romio/adio/common/shfp_fname.c
index 849f678..5c84381 100644
--- a/src/mpi/romio/adio/common/shfp_fname.c
+++ b/src/mpi/romio/adio/common/shfp_fname.c
@@ -88,8 +88,8 @@ void ADIOI_Shfp_fname(ADIO_File fd, int rank, int *error_code)
 	}
 	    
 	MPL_snprintf(tmp, 128, ".shfp.%d.%d", pid, i);
-	/* ADIOI_Strnapp will return non-zero if truncated.  That's ok */
-	ADIOI_Strnapp(fd->shared_fp_fname, tmp, PATH_MAX);
+	/* MPL_strnapp will return non-zero if truncated.  That's ok */
+	MPL_strnapp(fd->shared_fp_fname, tmp, PATH_MAX);
 	
 	len = (int)strlen(fd->shared_fp_fname);
 	MPI_Bcast(&len, 1, MPI_INT, 0, fd->comm);
-- 
MPICH primary repository


More information about the commits mailing list